// Intel's UPnP .NET Framework Device Stack, Device Module
// Intel Device Builder Build#1.0.1868.18043

using System;
using Intel.UPNP;
using Light;
using System.Windows.Forms;

namespace Light
{
	/// <summary>
	/// Summary description for SampleDevice.
	/// </summary>
	public class SampleDevice
	{
		private UPnPDevice device;
        private Form1 form;
        private Light.DimmingService DimmingService;
        private Light.SwitchPower SwitchPower;
		
		public SampleDevice(Form1 form)
		{
            this.form = form;

            // Device creation
            device = UPnPDevice.CreateRootDevice(1800, 1.0, "\\");
			device.FriendlyName = "Light";
			device.Manufacturer = "Rainbow";
			device.ManufacturerURL = "http://rainbow.i3s.unice.fr/";
			device.ModelName = "Stéphane's Light";
			device.ModelDescription = "Home Automation Light";
			device.ModelNumber = "X1";
			device.HasPresentation = false;
			device.DeviceURN = "urn:schemas-upnp-org:device:Light:1";

            // Add Dimming service
            DimmingService = new Light.DimmingService();
			DimmingService.External_GetLoadLevelStatus = new Light.DimmingService.Delegate_GetLoadLevelStatus(DimmingService_GetLoadLevelStatus);
			DimmingService.External_GetMaxLevel = new Light.DimmingService.Delegate_GetMaxLevel(DimmingService_GetMaxLevel);
			DimmingService.External_GetMinLevel = new Light.DimmingService.Delegate_GetMinLevel(DimmingService_GetMinLevel);
			DimmingService.External_SetLoadLevelStatus = new Light.DimmingService.Delegate_SetLoadLevelStatus(DimmingService_SetLoadLevelStatus);
			device.AddService(DimmingService);

            // Add SwitchPower service
            SwitchPower = new Light.SwitchPower();
			SwitchPower.External_GetStatus = new Light.SwitchPower.Delegate_GetStatus(SwitchPower_GetStatus);
			SwitchPower.External_Off = new Light.SwitchPower.Delegate_Off(SwitchPower_Off);
			SwitchPower.External_On = new Light.SwitchPower.Delegate_On(SwitchPower_On);
			SwitchPower.External_SetStatus = new Light.SwitchPower.Delegate_SetStatus(SwitchPower_SetStatus);
			device.AddService(SwitchPower);
			
			// Setting the initial value of evented variables
			DimmingService.Evented_LoadLevelStatus = 100;
			SwitchPower.Evented_Status = false;
		}

        public void Start(int port)
        {
            device.StartDevice(port);
        }

        public void Start()
		{
			device.StartDevice();
		}
		
		public void Stop()
		{
			device.StopDevice();
		}
		
		public System.Byte DimmingService_GetLoadLevelStatus()
		{
            return DimmingService.GetLoadLevelStatus();
        }
		
		public System.Byte DimmingService_GetMaxLevel()
		{
            return 100;
        }
		
		public System.Byte DimmingService_GetMinLevel()
		{
            return 0;
        }
		
		public void DimmingService_SetLoadLevelStatus(System.Byte newValue)
		{
            DimmingService.SetLoadLevelStatus(newValue);

            if (SwitchPower.GetStatus())
                form.setLevelImage(newValue);
        }
		
		public System.Boolean SwitchPower_GetStatus()
		{
            return SwitchPower.GetStatus();
        }
		
		public void SwitchPower_Off()
		{
            SwitchPower.Off();
            form.setLevelImage(0);
        }
		
		public void SwitchPower_On()
		{
            SwitchPower.On();
            form.setLevelImage(this.DimmingService_GetLoadLevelStatus());
        }
		
		public void SwitchPower_SetStatus(System.Boolean newValue)
		{
            SwitchPower.SetStatus(newValue);
            if (newValue)
            {
                form.setLevelImage(DimmingService_GetLoadLevelStatus());
            }
            else
            {
                form.setLevelImage(0);
            }
        }
	}
}

